![Python package](https://github.com/sensein/cmixf/workflows/Python%20package/badge.svg?branch=master)

# cmixf

A library to parse [CMIXF-12](https://people.csail.mit.edu/jaffer/MIXF/CMIXF-12).

This will install a CLI `cmixf` when installed.

At present this assumes that a number is provided before any unit.

## For developers:

After cloning the repo do:

1. pip install -e .[dev]
2. pre-commit install
